summaryrefslogtreecommitdiff
path: root/include/http_request.h
diff options
context:
space:
mode:
authorStas Bekman <stas@apache.org>2004-08-20 20:58:49 +0000
committerStas Bekman <stas@apache.org>2004-08-20 20:58:49 +0000
commit0226c056ec34b508a1b7114175ea2b62b18db32f (patch)
tree14688287d43f9080f7829852e196e2fa6a452402 /include/http_request.h
parent8887c5d6c06a023ed3026879a25fc0fc0d0ee5d6 (diff)
downloadhttpd-0226c056ec34b508a1b7114175ea2b62b18db32f.tar.gz
use more intuitive variable names
ap_sub_req_*_uri to use new_uri ap_sub_req_*_file to use new_file PR: Obtained from: Submitted by: Reviewed by: git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@104758 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/http_request.h')
-rw-r--r--include/http_request.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/include/http_request.h b/include/http_request.h
index 4ae74e398b..241262acf7 100644
--- a/include/http_request.h
+++ b/include/http_request.h
@@ -62,21 +62,21 @@ AP_DECLARE(int) ap_process_request_internal(request_rec *r);
/**
* Create a sub request from the given URI. This sub request can be
* inspected to find information about the requested URI
* @param new_file The URI to lookup
* @param r The current request
* @param next_filter The first filter the sub_request should use. If this is
* NULL, it defaults to the first filter for the main request
* @return The new request record
- * @deffunc request_rec * ap_sub_req_lookup_uri(const char *new_file, const request_rec *r)
+ * @deffunc request_rec * ap_sub_req_lookup_uri(const char *new_uri, const request_rec *r)
*/
-AP_DECLARE(request_rec *) ap_sub_req_lookup_uri(const char *new_file,
+AP_DECLARE(request_rec *) ap_sub_req_lookup_uri(const char *new_uri,
const request_rec *r,
ap_filter_t *next_filter);
/**
* Create a sub request for the given file. This sub request can be
* inspected to find information about the requested file
- * @param new_file The URI to lookup
+ * @param new_file The file to lookup
* @param r The current request
* @param next_filter The first filter the sub_request should use. If this is
* NULL, it defaults to the first filter for the main request
@@ -113,15 +113,15 @@ AP_DECLARE(request_rec *) ap_sub_req_lookup_dirent(const apr_finfo_t *finfo,
* Create a sub request for the given URI using a specific method. This
* sub request can be inspected to find information about the requested URI
* @param method The method to use in the new sub request
* @param new_file The URI to lookup
* @param r The current request
* @param next_filter The first filter the sub_request should use. If this is
* NULL, it defaults to the first filter for the main request
* @return The new request record
* @deffunc request_rec * ap_sub_req_method_uri(const char *method, const char *new_file, const request_rec *r)
*/
AP_DECLARE(request_rec *) ap_sub_req_method_uri(const char *method,
- const char *new_file,
+ const char *new_uri,
const request_rec *r,
ap_filter_t *next_filter);
/**
@@ -289,8 +289,8 @@ AP_DECLARE_HOOK(int,translate_name,(request_rec *r))
* @param r The current request
* @return DONE (or HTTP_) if this contextless request was just fulfilled
* (such as TRACE), OK if this is not a file, and DECLINED if this is a file.
- * The core map_to_storage (HOOK_RUN_LAST) will directory_walk and file_walk
- * the r->filename.
+ * The core map_to_storage (HOOK_RUN_REALLY_LAST) will directory_walk
+ * and file_walk the r->filename.
*
* @ingroup hooks
*/
@@ -62,21 +62,21 @@ AP_DECLARE(int) ap_process_request_internal(request_rec *r);
* Create a sub request from the given URI. This sub request can be
* inspected to find information about the requested URI
- * @param new_file The URI to lookup
+ * @param new_uri The URI to lookup
* @param r The current request
* @param next_filter The first filter the sub_request should use. If this is
@@ -113,15 +113,15 @@ AP_DECLARE(request_rec *) ap_sub_req_lookup_dirent(const apr_finfo_t *finfo,
* sub request can be inspected to find information about the requested URI
* @param method The method to use in the new sub request
- * @param new_file The URI to lookup
+ * @param new_uri The URI to lookup
* @param r The current request
* @param next_filter The first filter the sub_request should use. If this is
@@ -113,15 +113,15 @@ AP_DECLARE(request_rec *) ap_sub_req_lookup_dirent(const apr_finfo_t *finfo,
* NULL, it defaults to the first filter for the main request
* @return The new request record
- * @deffunc request_rec * ap_sub_req_method_uri(const char *method, const char *new_file, const request_rec *r)
+ * @deffunc request_rec * ap_sub_req_method_uri(const char *method, const char *new_uri, const request_rec *r)
*/
AP_DECLARE(request_rec *) ap_sub_req_method_uri(const char *method,